==> haskell-markdown-unlit-0.6.0-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-EK6OIKU3aYk5c9H7HP4i0T
key:                  markdown-unlit-0.6.0-EK6OIKU3aYk5c9H7HP4i0T
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  e16c93671979fe0bfe926d47b40d9d4c
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-EK6OIKU3aYk5c9H7HP4i0T
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-markdown-unlit-0.6.0-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 markdown-unlit
version:              0.6.0
visibility:           public
id:                   markdown-unlit-0.6.0-4M87QVOnc57B551cOsW29m
key:                  markdown-unlit-0.6.0-4M87QVOnc57B551cOsW29m
license:              MIT
copyright:            (c) 2012-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  1b34398040712fd3da91e058c7164391
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/markdown-unlit-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.6.0-4M87QVOnc57B551cOsW29m
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
